<?php
/**
 * Implement Custom Header functionality for stone
 *
 * @package Stone
 * @since Stone 1.0
 */

/**
 * ------------------------------------------------------------------------------------------------- 
 * Set up the WordPress core custom header settings.
 *
 * @since Stone 1.0
 *
 * @uses stone_header_style()
 * @uses stone_admin_header_style()
 * @uses stone_admin_header_image()
 * -------------------------------------------------------------------------------------------------
 */

function stone_custom_header_setup() {
	/**
	 * Filter stone custom-header support arguments.
	 *
	 * @since Stone 1.0
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type bool   $header_text            Whether to display custom header text. Default false.
	 *     @type int    $width                  Width in pixels of the custom header image. Default 1260.
	 *     @type int    $height                 Height in pixels of the custom header image. Default 240.
	 *     @type bool   $flex_height            Whether to allow flexible-height header images. Default true.
	 *     @type string $admin_head_callback    Callback function used to style the image displayed in
	 *                                          the Appearance > Header screen.
	 *     @type string $admin_preview_callback Callback function used to create the custom header markup in
	 *                                          the Appearance > Header screen.
	 * }
	 */
	 
	add_theme_support( 'custom-header', apply_filters( 'stone_custom_header_args', array(
		'default-image' => get_template_directory_uri() . '/images/headers/stones.jpg',
		'default-text-color'     => '333',
		'width'                  => 1260,
		'height'                 => 300,
		'flex-height'            => false,
		'wp-head-callback'       => 'stone_header_style',
		'admin-head-callback'    => 'stone_admin_header_style',
		'admin-preview-callback' => 'stone_admin_header_image',
	) ) );
}

add_action( 'after_setup_theme', 'stone_custom_header_setup' );

/**
 * ------------------------------------------------------------------------------------------------- 
 * Styles the header image and text displayed on the blog
 *
 * @see stone_custom_header_setup().
 * -------------------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'stone_header_style' ) ) :
	function stone_header_style() {
		
		$text_color = get_header_textcolor();

		// If no custom color for text is set, let's bail.
		if ( display_header_text() && $text_color === get_theme_support( 'custom-header', 'default-text-color' ) )
			return;

		// If we get this far, we have custom styles.
		?>
		<style type="text/css" id="stone-header-css">
			<?php
			// Has the text been hidden?
			if ( ! display_header_text() ) :
				?>
			.site-title,
			.site-description {
				clip: rect(1px 1px 1px 1px); /* IE7 */
				clip: rect(1px, 1px, 1px, 1px);
				position: absolute;
			}
				<?php
			
			// If the user has set a custom color for the text, use that.
			elseif ( $text_color != get_theme_support( 'custom-header', 'default-text-color' ) ) :
				?>
			.site-title,
			.site-description {
				color: #<?php echo esc_attr( $text_color ); ?>;
			}
				<?php 
			endif; 
			?>
		</style>
		<?php
	}
endif; // stone_header_style


/**
 * ------------------------------------------------------------------------------------------------- 
 * Style the header image displayed on the Appearance > Header screen.
 *
 * @see stone_custom_header_setup()
 *
 * @since Stone 1.0
 * -------------------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'stone_admin_header_style' ) ) :
	function stone_admin_header_style() {
	?>
		<style type="text/css" id="stone-admin-header-css">
		.appearance_page_custom-header #headimg {
			background-color: #000;
			border: none;
			max-width: 1260px;
			min-height: 48px;
		}
		#headimg h1 {
			font-family: 'Montserrat', sans-serif;
			font-size: 18px;
			line-height: 48px;
			margin: 0 0 0 30px;
		}
		.rtl #headimg h1  {
			margin: 0 30px 0 0;
		}
		#headimg h1 a {
			color: #fff;
			text-decoration: none;
		}
		#headimg img {
			vertical-align: middle;
		}
		</style>
	<?php
	}
endif; // stone_admin_header_style

/**
 * ------------------------------------------------------------------------------------------------- 
 * Create the custom header image markup displayed on the Appearance > Header screen.
 *
 * @see stone_custom_header_setup()
 *
 * @since Stone 1.0
 * -------------------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'stone_admin_header_image' ) ) :
	function stone_admin_header_image() {
	?>
		<div id="headimg">
			<?php if ( get_header_image() ) : ?>
			<img src="<?php header_image(); ?>" alt="">
			<?php endif; ?>
			<h1 class="displaying-header-text"><a id="name" style="<?php echo esc_attr( sprintf( 'color: #%s;', get_header_textcolor() ) ); ?>" onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>" tabindex="-1"><?php bloginfo( 'name' ); ?></a></h1>
		</div>
	<?php
	}
endif; // stone_admin_header_image

?>